qr: QR decomposition of an HDF5Matrix

View source: R/S3_factorizations.R

qrR Documentation

QR decomposition of an HDF5Matrix

Description

Overrides base::qr() to dispatch on HDF5Matrix objects. For plain R matrices the call is forwarded to base::qr().

Usage

qr(x, ...)

Arguments

x

An HDF5Matrix or a plain R matrix/vector.

...

Additional arguments passed to qr.HDF5Matrix() or ignored for qr.default().

Value

For HDF5Matrix: a named list with elements Q and R (both HDF5Matrix). For plain R objects: the result of base::qr().

See Also

qr.HDF5Matrix, chol.HDF5Matrix, solve.HDF5Matrix


BigDataStatMeth documentation built on May 15, 2026, 1:07 a.m.