Computes A - B element-wise for two HDF5 datasets referenced by
external pointers, using a block-wise algorithm.
rcpp_hdf5dataset_subtract(
ptr_a,
ptr_b,
paral = NULL,
block_size = NULL,
threads = NULL,
compression = NULL
)Named list with filename and path of the result.
The result is stored in group "OUTPUT" with dataset name
"A_plus_B" (resp. "A_minus_B", "A_times_B",
"A_div_B") where A and B are the input dataset names.
External pointer (SEXP) for matrix A
External pointer (SEXP) for matrix B
Logical or NULL; enable OpenMP parallelisation
Integer or NULL; block size (NULL = auto)
Integer or NULL; thread count