| bdCreate_hdf5_group | R Documentation |
Create a (nested) group inside an HDF5 file. The operation is idempotent: if the group already exists, no error is raised.
bdCreate_hdf5_group(filename, group)
filename |
Character string. Path to the HDF5 file. |
group |
Character string. Group path to create
(e.g., |
Intermediate groups are created when needed. The HDF5 file must exist prior to the call (create it with a writer function).
List with components:
Character string with the HDF5 filename
Character string with the full group path created within the HDF5 file
The HDF Group. HDF5 User's Guide.
hdf5_create_matrix.
fn <- tempfile(fileext = ".h5")
hdf5_create_matrix(fn, "tmp/seed", data = matrix(0, 1, 1))
bdCreate_hdf5_group(fn, "MGCCA_OUT/scores")
hdf5_close_all()
unlink(fn)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.