| bdCreate_hdf5_matrix | R Documentation |
Creates a HDF5 file with numerical data matrix,
bdCreate_hdf5_matrix(
filename,
object,
group = NULL,
dataset = NULL,
transp = NULL,
overwriteFile = NULL,
overwriteDataset = NULL,
unlimited = NULL
)
filename |
character array indicating the name of the file to create |
object |
numerical data matrix |
group |
character array indicating folder name to put the matrix in HDF5 file |
dataset |
character array indicating the dataset name to store the matrix data |
transp |
boolean, if trans=true matrix is stored transposed in HDF5 file |
overwriteFile |
optional boolean by default overwriteFile = false, if true and file exists, removes old file and creates a new file with de dataset data. |
overwriteDataset |
optional boolean by default overwriteDataset = false, if true and dataset exists, removes old dataset and creates a new dataset. |
unlimited |
optional boolean by default unlimited = false, if true creates a dataset that can growth. |
List with components:
Character string with the HDF5 filename
Character string with the full dataset path to the created matrix (group/dataset)
fn <- tempfile(fileext = ".h5")
matA <- matrix(c(1,2,3,4,5,6,7,8,9,10,11,12,13,14,15), nrow = 3, byrow = TRUE)
bdCreate_hdf5_matrix(filename = fn,
object = matA, group = "datasets",
dataset = "datasetA", transp = FALSE,
overwriteFile = TRUE,
overwriteDataset = TRUE,
unlimited = FALSE)
hdf5_close_all()
unlink(fn)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.