| bdScalarwproduct | R Documentation |
Multiplies a numeric matrix A by a scalar weight w,
returning w * A. The input must be a base R numeric matrix (or
convertible to one).
bdScalarwproduct(A, w)
A |
Numeric matrix (or object convertible to a dense numeric matrix). |
w |
Numeric scalar weight. |
A numeric matrix with the same dimensions as A.
set.seed(1234)
n <- 5; p <- 3
X <- matrix(rnorm(n * p), n, p)
w <- 0.75
bdScalarwproduct(X, w)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.