| rcpp_hdf5_close_at_paths | R Documentation |
Scans the live-pointer registry for any open hdf5Dataset objects
that match the given filename and any of the paths.
Each matching object is closed and its external pointer cleared, so
that any R6 HDF5Matrix objects holding those pointers will
return FALSE from is_valid() immediately.
This is called automatically by R6 methods that use
overwrite = TRUE (e.g. $eigen(), $svd(),
$qr(), $chol(), $prcomp()) to ensure that
previous result objects are safely invalidated before the HDF5 datasets
they reference are deleted and recreated.
rcpp_hdf5_close_at_paths(filename, paths)
filename |
Canonical filesystem path to the HDF5 file. |
paths |
Character vector of HDF5-internal paths
(e.g. |
NULL invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.